@@ -1,7 +1,9 @@
+from typing import Callable
+from matplotlib.artist import Artist
 import matplotlib.pyplot as plt
 import matplotlib.animation as anim
 
-def Show(lst, callable, speed = 0.5, sortKey = lambda x:x):
+def Show(lst:list, callable:Callable, speed:float = 0.5, sortKey:Callable = lambda x:x) -> None:
     '''
     A function to visualise sorting animations
     Args: 
@@ -13,13 +15,19 @@ def Show(lst, callable, speed = 0.5, sortKey = lambda x:x):
     epochs = [-2]
     frames = list(callable(lst, animate=True, key=sortKey))
     fig, ax = plt.subplots()
+    texts = []
 
     def add_labels(lst):
         for i in range(len(lst)):
-            plt.text(i, lst[i], lst[i], ha = 'center')
+            texts.append(plt.text(i, lst[i], lst[i], ha = 'center'))
+
+    def remove_labels(lst):
+        for frame in lst:
+            Artist.remove(frame)
+        lst.clear()
 
     def update_plot(x, rec, epochs, frames):
-        ax.texts = []
+        remove_labels(texts)
         epochs[0] += 1
         for rec, val in zip(rec, x):
             rec.set_height(val)
@@ -30,7 +38,7 @@ def Show(lst, callable, speed = 0.5, sortKey = lambda x:x):
     _ = anim.FuncAnimation(fig, func=update_plot, fargs=(bar_rec, epochs, frames), frames=frames, interval=speed*1000, repeat=False)
     plt.show()
 
-def Print(lst, callable, sortKey = lambda x:x):
+def Print(lst:list, callable:Callable, sortKey:Callable = lambda x:x) -> None:
     '''
     A function to print the current state of list after every iteration
     Args: 
